Description
-------------------
Simple Scanner to scan port.Example:import SnakeScan
and use module to scan port 
if him not run install in pip art,tqdm,termcolor and run.
added new single search example:
    
[$]Port--> --s 50
requires-python=>3.1.1
added new check all port search:
 [$]Port--> --a 
 
 